ReauthorizeParams class
Reauthorize Params
Constructors
-
Request parameters for
reauthorizemethod calls.const
Properties
- authToken → AuthToken
-
An opaque string previously returned by a call to
authorize,reauthorize, orcloneAuthorization.final - hashCode → int
-
The hash code for this object.
no setterinherited
- identity → AppIdentity
-
The dApp's identity information.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialises
thisclass into a JSON object. -
toString(
) → AuthToken -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited